package org.springblade.modules.api.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.common.constant.CommonConstant;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.business.entity.Shop;
import org.springblade.modules.business.service.IShopService;
import org.springblade.modules.business.vo.ShopVO;
import org.springblade.modules.business.wrapper.ShopWrapper;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@RestController
@AllArgsConstructor
@RequestMapping(CommonConstant.API_URL + "/shop")
@Api(value = "门店管理接口", tags = "门店管理接口")
public class ApiShopController {

    private final IShopService iShopService;

    @PostMapping("/add")
    @ApiOperationSupport(order = 1)
    @ApiOperation(value = "添加门店", notes = "传入shop")
    public R<Void> save(@Valid @RequestBody Shop shop) {
        shop.setMerchantId(AuthUtil.getUserId());
        return R.status(iShopService.save(shop));
    }

    @PostMapping("/update")
    @ApiOperationSupport(order = 2)
    @ApiOperation(value = "修改门店", notes = "传入shop")
    public R<Void> update(@Valid @RequestBody Shop shop) {
        return R.status(iShopService.updateById(shop));
    }

    /**
     * 自定义分页 门店表
     */
    @GetMapping("/page")
    @ApiOperationSupport(order = 3)
    @ApiOperation(value = "分页查询门店列表", notes = "传入shop")
    public R<IPage<ShopVO>> page(ShopVO shop, Query query) {
        shop.setMerchantId(AuthUtil.getUserId());
        IPage<ShopVO> pages = iShopService.selectShopPage(Condition.getPage(query), shop);
        return R.data(pages);
    }

    @GetMapping("/detail")
    @ApiOperationSupport(order = 4)
    @ApiOperation(value = "门店详情", notes = "传入shop")
    public R<ShopVO> detail(@ApiParam(value = "门店id", required = true) @RequestParam Long id) {
        Shop detail = iShopService.getById(id);
        return R.data(ShopWrapper.build().entityVO(detail));
    }

    /**
     * 删除 门店表
     */
    @PostMapping("/remove")
    @ApiOperationSupport(order = 5)
    @ApiOperation(value = "删除", notes = "传入ids")
    public R<Void> remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        return R.status(iShopService.removeByIds(Func.toLongList(ids)));
    }

}
